//
//  ZegoTypes.h
//  ZegoAvatar
//
//  Created by justinsong on 2021/11/25.
//

#ifndef ZegoTypes_h
#define ZegoTypes_h

#import <CoreVideo/CoreVideo.h>
#import <Foundation/Foundation.h>

@class ZegoExpression;
@class ZegoPoseInfo;
@class ZegoFaceExpression;
@class ZegoImageParam;

/// 推理表情数据回调
///
/// Description: AI 引擎通过摄像头画面或者麦克风音频数据推理出表情并且回调。
///
/// @param expression 表情数据
typedef void (^ZegoAvatarExpressionCallback)(ZegoExpression *expression);

/// 推理肢体动作回调
///
/// Description: AI 引擎通过摄像头画面推理出肢体信息并且回调。
///
/// @param expression 肢体信息
typedef void (^ZegoAvatarPoseCallback)(unsigned long expression);

/// 摄像头纹理回调
///
/// Description: 在调用 [startDetectHandClassify:] 或者 [startDetectPose] 后回调摄像头纹理。
///
/// @param buffer 纹理
/// @param param 纹理参数
typedef void (^ZegoAvatarCameraFrameCallback)(CVPixelBufferRef buffer, ZegoImageParam *param);

/// 设置 Avatar 角色的回调
///
/// Description: 设置角色后，在绘制角色的第一帧完成时回调，只回调一次。
typedef void (^ZegoAvatarCharacterCallback)(void);

/// 播放动画回调
///
/// Description: 在动画完成后回调。
///
/// @param errorCode 错误码
typedef void (^ZegoAvatarAnimationCallback)(int errorCode);

/// 播放多人动画回调
///
/// Description: 在动画完成后回调。
///
/// @param errorCode 错误码
typedef void (^ZegoAvatarMultiCharacterAnimationCallback)(int errorCode);

/// 设置角色素材资源包回调
///
/// Description: 在设置资源完成时回调。
///
/// @param errorCode 错误码
typedef void (^ZegoAvatarSetPacakgeCallback)(int errorCode);

/// 装扮改变回调
///
/// Description: 装扮发生改变时回调，需要调用 [registerAvatarMakeupUpdateEvent] 注册监听。
///
/// @param makeupType 素材类型
/// @param packageID 素材ID
typedef void (^ZegoAvatarMakeupUpdateCallback)(NSString *makeupType, NSString *packageID);

/// AvatarView 纹理回调
///
/// Description: 回调 AvatarView 的纹理ID。
///
/// @param texture 纹理ID
typedef void (^ZegoAvatarViewTextureUpdateCallback)(id<MTLTexture> texture, int width, int height);

/// SDK 错误码
///
/// Description:
///  1开头的为未知错误
///  5开头为鉴权相关错误码
///  6开头的为SDK相关错误码
///  7开头的为AI相关错误码
///  成功返回0
typedef NS_ENUM(NSInteger, ZegoAvatarErrorCode) {
    // 成功
    ZegoAvatarErrorCodeSuccess = 0,
    // 证书格式非法
    ZegoAvatarErrorCodeLicenseFormatInvalid = 5000001,
    // 证书已过期
    ZegoAvatarErrorCodeLicenseExpired = 5000002,
    // 当前平台不支持该证书
    ZegoAvatarErrorCodeLicensePlatformInvalid = 5000004,
    // 当前应用不支持该证书
    ZegoAvatarErrorCodeLicenseInvalid = 5000005,
    // 未初始化证书
    ZegoAvatarErrorCodeLicenseNotInit = 5000006,
    //参数有误。请检查您的输入参数 AppID 是否正确, AppSign 是否为空。
    ZegoAvatarErrorCodeLicenseParamInvalid = 5000101,
    //Token（AppSign）有误。AppSign不正确，请联系 ZEGO 技术支持处理。
    ZegoAvatarErrorCodeLicenseTokenInvalid = 5000102,
    //证书无效。AppId 或者包名不正确、或不匹配。请联系 ZEGO 技术支持确认代码和配置是否正确。
    ZegoAvatarErrorCodeLicenseBundleIDInvalid = 5000103,
    ///服务内部问题。请联系 ZEGO 技术支持处理。
    ZegoAvatarErrorCodeLicenseServerError = 5000104,
    ///其他网络错误，请检查网络
    ZegoAvatarErrorCodeLicenseNetworkError = 5000105,
    // 证书不支持的特性
    ZegoAvatarErrorCodeFeaturesNotSupport = 5000200,
    // 证书不支持AI捏脸特性
    ZegoAvatarErrorCodeAIFaceEditInvalid = 5000201,
    // 证书不支持手动捏脸换装特性
    ZegoAvatarErrorCodeManualFaceEditInvalid = 5000202,
    // 证书不支持表情随动特性
    ZegoAvatarErrorCodeExpressionMirroringInvalid = 5000203,
    // 缺少可用的License，检查鉴权是否成功
    ZegoAvatarErrorCodeHaveNoVaildLicense = 5000204,
    // 指定的文件不存在
    ZegoAvatarErrorCodeFileDoesNotExist = 5000205,
    // 证书不支持声音随动特性
    ZegoAvatarErrorCodeAudioMirroringInvalid = 5000206,
    // 初始化失败，内存不足
    ZegoAvatarErrorCodeOOMInitFailed = 5000301,
    /// 录制输出文件创建错误
    ZegoAvatarErrorCodeRecordCreateFileError = 6000001,
    /// 录制出错
    ZegoAvatarErrorCodeRecordError = 6000002,
    /// 正在录制
    ZegoAvatarErrorCodeFileRecording = 6000003,
    /// 录制宽度设置错误
    ZegoAvatarErrorCodeRecordResizeFailed = 6000004,
    /// 录制硬件能力不支持
    ZegoAvatarErrorCodeRecordCapabilitiesFailed = 6000005,
    /// 录制硬件配置出错
    ZegoAvatarErrorCodeRecordConfigFailed = 6000006,
    /// 录制音频硬件配置出错
    ZegoAvatarErrorCodeRecordingAudioSupportFailed = 6000007,
    /// 摄像头打开失败
    ZegoAvatarErrorCodeCameraNull = 6000100,
    /// 没有权限打开摄像头
    ZegoAvatarErrorCodeCameraPermission = 6000101,
    /// 没有权限打开麦克风
    ZegoAvatarErrorCodeAudioPermission = 6000102,
    /// 传入路径为空
    ZegoAvatarErrorCodePathEmpty = 6000200,
    /// 路径不存在
    ZegoAvatarErrorCodePathNoExist = 6000201,
    /// 创建模型失败
    ZegoAvatarErrorCodeCreateCharacterError = 6000300,
    /// 模型资源路径错误
    ZegoAvatarErrorCodeCreateCharacterPathError = 6000301,
    /// 上下文为空
    ZegoAvatarErrorCodeContextNullError = 6000400,
    /// 使用被销毁的view
    ZegoAvatarErrorCodeViewHasDestroyed = 6000401,
    /// avatar推流缺少character
    ZegoAvatarErrorCodeAvatarStreamMissingCharacter = 6000500,
    /// 不可推流
    ZegoAvatarErrorCodeAvatarStreamUnavailable = 6000501,
    /// 脸基尼-metal 系统兼容性错误
    ZegoAvatarErrorCodeAvatarFaceMaskMetalIncompatible = 7000001,
    /// 脸基尼-没有收到相机数据，请检查相机设置或者输入相机数据
    ZegoAvatarErrorCodeAvatarFaceMaskNoneCameraInputData = 7000002,
    /// 脸基尼-没有该模块的license权限
    ZegoAvatarErrorCodeAvatarFaceMaskPermissionDenied = 7000003,
    /// 未知错误
    ZegoAvatarErrorCodeUnknownError = 1000001,
};

/// ZegoAvatarService 初始化状态枚举
typedef NS_ENUM(NSInteger, ZegoAvatarServiceState) {
    /// 未初始化
    ZegoAvatarServiceStateUnInit = 0,
    /// 初始化中
    ZegoAvatarServiceStateDuringInit = 1,
    /// 初始化失败
    ZegoAvatarServiceStateInitFailed = 2,
    /// 初始化成功
    ZegoAvatarServiceStateInitSucceed = 3,
};

/// Avatar 性别
typedef NS_ENUM(NSUInteger, ZegoGenderType) {
    /// 男
    ZegoGenderTypeMale = 0,
    /// 女
    ZegoGenderTypeFemale = 1,
    /// 未知
    ZegoGenderTypeUnknow = 2
};

/// AI检测出的人脸特征维度  [ZegoInteractEngine 返回的特征维度]
typedef NS_ENUM(NSUInteger, ZegoFaceShapeType) {
    /// 眉毛厚度
    ZegoFaceShapeTypeEyebrowThickness = 0,
    /// 眉毛长度
    ZegoFaceShapeTypeEyebrowLength = 1,
    /// 眉毛高度
    ZegoFaceShapeTypeEyebrowHeight = 2,
    /// 眉毛旋转
    ZegoFaceShapeTypeEyebrowRotation = 3,
    /// 眼睛大小
    ZegoFaceShapeTypeEyeSize = 4,
    /// 眼睛高度
    ZegoFaceShapeTypeEyeHeight = 5,
    /// 眼睛旋转
    ZegoFaceShapeTypeEyeRotation = 6,
    /// 眼睛眼距
    ZegoFaceShapeTypeEyeDistance = 7,
    /// 鼻子宽度
    ZegoFaceShapeTypeNoseWidth = 8,
    /// 鼻子高度
    ZegoFaceShapeTypeNoseHeight = 9,
    /// 鼻头旋转
    ZegoFaceShapeTypeNoseRotationX = 10,
    /// 鼻翼旋转
    ZegoFaceShapeTypeNoseRotationY = 11,
    /// 嘴巴上下
    ZegoFaceShapeTypeMouthPosition = 12,
    /// 嘴巴厚度
    ZegoFaceShapeTypeMouthThickness = 13,
    /// 嘴角旋转
    ZegoFaceShapeTypeMouthRotation = 14,
    /// 上唇宽度
    ZegoFaceShapeTypeUpperLipWidth = 15,
    /// 下唇宽度
    ZegoFaceShapeTypeLowerLipWidth = 16,
    /// 下巴宽度
    ZegoFaceShapeTypeJawWidth = 17,
    /// 下巴高度
    ZegoFaceShapeTypeJawHeight = 18,
    /// 脸颊宽度
    ZegoFaceShapeTypeCheeksWidth = 19,
};

/// Avatar 质量
typedef NS_ENUM(NSInteger, ZegoAvatarQualityLevel) {
    /// 高
    ZegoAvatarQualityLevelHigh = 0,
    /// 中
    ZegoAvatarQualityLevelMedium = 10,
    /// 低
    ZegoAvatarQualityLevelLow = 20,
};

/// Avatar 视图录制模式
typedef NS_ENUM(NSInteger, ZegoAvatarRecordMode) {
    /// 带透明度的 mov
    ZegoAvatarRecordModeMov = 1,
    /// 不带透明度的 mp4
    ZegoAvatarRecordModeMP4 = 2,
};

/// AI检测出的头发长度类型
typedef NS_ENUM(NSInteger, ZegoHairLengthType) {
    /// 中长散发
    ZegoHairLengthTypeLongLoose = 1,
    /// 中长捆发
    ZegoHairLengthTypeLongTie = 2,
    /// 短发
    ZegoHairLengthTypeShort = 3,
    /// 超短
    ZegoHairLengthTypeShorter = 4,
    /// 板寸
    ZegoHairLengthTypeShortest = 5,
};

/// AI检测出的头发刘海类型
typedef NS_ENUM(NSInteger, ZegoHairBangsType) {
    /// 无刘海,无偏
    ZegoHairBangsType0 = 1,
    /// 无刘海,左偏
    ZegoHairBangsType1 = 2,
    /// 无刘海,右偏
    ZegoHairBangsType2 = 3,
    /// 无刘海,中分
    ZegoHairBangsType3 = 4,
    /// 刘海全遮
    ZegoHairBangsType4 = 5,
    /// 有刘海，左偏
    ZegoHairBangsType5 = 6,
    /// 有刘海，右偏
    ZegoHairBangsType6 = 7,
    /// 有刘海，中分
    ZegoHairBangsType7 = 8,
    /// 有刘海，无分半截
    ZegoHairBangsType8 = 9,
};

/// AI检测出的头发马尾类型
typedef NS_ENUM(NSInteger, ZegoHairPonytailType) {
    /// 有马尾
    ZegoHairPonytailTypeHas = 1,
    /// 无马尾
    ZegoHairPonytailTypeNone = 2,
};

/// 图像的颜色格式类型
typedef NS_ENUM(NSInteger, ZegoImageFormat) {
    /// BGRA
    ZegoImageFormatBGRA = 0,
    /// YUV_NV12
    ZegoImageFormatYUVNV12 = 1,
};

/// Avatar 角色装扮类型
typedef NS_ENUM(NSInteger, ZegoAvatarMakeupType) {
    /// 头发
    ZegoAvatarMakeupTypeHair = 1,
    /// 帽子
    ZegoAvatarMakeupTypeCap = 2,
    /// 套装
    ZegoAvatarMakeupTypeSuit = 3,
    /// 鞋子
    ZegoAvatarMakeupTypeShoes = 4,
    /// 裤子
    ZegoAvatarMakeupTypePants = 5,
    /// 裙子
    ZegoAvatarMakeupTypeSkirt = 6,
    /// 上衣
    ZegoAvatarMakeupTypeCoat = 7,
    /// 头饰
    ZegoAvatarMakeupTypeHeadWear = 8,
    /// 耳饰
    ZegoAvatarMakeupTypeEarrings = 9,
    /// 耳机
    ZegoAvatarMakeupTypeHeadset = 10,
    /// 眼镜
    ZegoAvatarMakeupTypeGlasses = 11,
    /// 袜子
    ZegoAvatarMakeupTypeSocks = 12,
    /// 腿饰
    ZegoAvatarMakeupTypeLeglet = 13,
    /// 颈饰
    ZegoAvatarMakeupTypeNecklace = 14,
    /// 腰饰
    ZegoAvatarMakeupTypeBelt = 15,
    /// 戒指
    ZegoAvatarMakeupTypeRing = 16,
    /// 手环
    ZegoAvatarMakeupTypeBracelet = 17,
    /// 手套
    ZegoAvatarMakeupTypeMittens = 18,
    /// 面罩
    ZegoAvatarMakeupTypeMask = 19,
    /// 头套
    ZegoAvatarMakeupTypeHeadgear = 20,
    /// 连体服
    ZegoAvatarMakeupTypeOverall = 21,
    /// 背包道具
    ZegoAvatarMakeupTypeBack = 22,
    /// 手持道具
    ZegoAvatarMakeupTypeProp = 23,
    /// 美甲
    ZegoAvatarMakeupTypeNail = 24,
    /// 尾巴
    ZegoAvatarMakeupTypeTail = 25,
    /// 胡子
    ZegoAvatarMakeupTypeBeard = 26,
    /// 唇色
    ZegoAvatarMakeupTypeLipColor = 27,
    /// 面部彩绘
    ZegoAvatarMakeupTypeFacePaint = 28,
    /// 睫毛
    ZegoAvatarMakeupTypeEyelash = 29,
    /// 眉毛
    ZegoAvatarMakeupTypeBrow = 30,
    /// 美瞳
    ZegoAvatarMakeupTypeContactLens = 31,
    /// 肤色
    ZegoAvatarMakeupTypeSkinColor = 32,
    /// 脸型
    ZegoAvatarMakeupTypeFaceShape = 33,
    /// 鼻型
    ZegoAvatarMakeupTypeNoseShape = 34,
    /// 眼型
    ZegoAvatarMakeupTypeEyeShape = 35,
    /// 眉型
    ZegoAvatarMakeupTypeBrowShape = 36,
    /// 唇形
    ZegoAvatarMakeupTypeLipShape = 37,
    /// 发色
    ZegoAvatarMakeupTypeHairColor = 38
};

/// Avatar 视图横竖屏展示类型
typedef NS_ENUM(NSInteger, ZegoAvatarPreferOrientation) {
    /// 竖屏
    ZegoAvatarPreferOrientationPortrait = 0,
    /// 横屏
    ZegoAvatarPreferOrientationLandscape = 1,
};

/// ZegoExpression 表情检测模式
typedef NS_ENUM(NSInteger, ZegoExpressionDetectMode) {
    /// 摄像头画面推理表情
    ZegoExpressionDetectModeCamera = 0,
    /// 麦克风声音推理表情
    ZegoExpressionDetectModeAudio = 1,
};

/// ZegoExpression 肢体驱动模式
typedef NS_ENUM(NSInteger, ZegoPoseDetectMode) {
    /// 不使用肢体驱动
    ZegoPoseDetectModeNone = 0,
    /// 全身驱动,暂不支持
    //  ZegoPoseDetectModeFull = 100,
    /// 半身驱动
    ZegoPoseDetectModeHalf = 101,
};

/// 手势识别类型
typedef NS_ENUM(NSInteger, ZegoHandPoseClassifyType) {
    /// 没有手
    ZegoHandPoseClassifyTypeNull = -1,
    /// 比心
    ZegoHandPoseClassifyTypeHeart = 0,
    /// OK
    ZegoHandPoseClassifyTypeOK = 1,
    /// 手张开
    ZegoHandPoseClassifyTypeOpen = 2,
    /// 握拳
    ZegoHandPoseClassifyTypeFist = 3,
    /// 讨红包
    ZegoHandPoseClassifyTypeSpread = 4,
    /// 点赞
    ZegoHandPoseClassifyTypeThumbUp = 5,
    /// 差评
    ZegoHandPoseClassifyTypeThumbDown = 6,
    /// 摇滚
    ZegoHandPoseClassifyTypeRock = 7,
    /// 食指朝上
    ZegoHandPoseClassifyTypeIndexUp = 8,
    /// 双指朝上
    ZegoHandPoseClassifyTypeTow = 9,
    /// 胜利(yeah)
    ZegoHandPoseClassifyTypeVictory = 10,
    /// 大V
    ZegoHandPoseClassifyTypeBigV = 11,
    /// 打电话
    ZegoHandPoseClassifyTypeCall = 12,
    /// 卷心菜
    ZegoHandPoseClassifyTypeCabbage = 13,
    /// 四个手指
    ZegoHandPoseClassifyTypeFour = 14,
    /// 发誓
    ZegoHandPoseClassifyTypeSwear = 15,
    /// 双指比枪
    ZegoHandPoseClassifyTypePistol2 = 16,
    /// 勾引
    ZegoHandPoseClassifyTypeSeduce = 17,
    /// 其他
    ZegoHandPoseClassifyTypeOther = 18,
};

/// 手势识别回调
///
/// Description: AI 引擎识别手势后回调。
///
/// @param type 识别类型
typedef void (^ZegoAvatarHandClassifyCallback)(ZegoHandPoseClassifyType type);

/// ZegoAvatarService的初始化配置
///
/// Description: 1.5.0及以上版本废弃，使用 ZegoServiceConfigV2 代替
@interface ZegoServiceConfig : NSObject

/// 鉴权获取的 license
@property (nonatomic, copy) NSString *license;

/// AI 模型资源的绝对路径
@property (nonatomic, copy) NSString *AIPath;

/// Unityframework 的路径，如果不填默认为app目录下的Frameworks/UnityFramework.framework
@property (nonatomic, copy) NSString *unityFrameworkPath;

/// UnityFramework.framework 的BundleID
@property (nonatomic, copy) NSString *unityBundleID;

/// SDK 支持的最小内存，小于该内存，不初始化 ZegoAvatarSDK
@property (nonatomic, assign) NSInteger minMemory;

@end

/// ZegoAvatarService的初始化配置V2版本
///
/// Description:
///  1.5.0及以上版本使用
///  SDK内部负责license缓存、更新、请求
@interface ZegoServiceConfigV2 : NSObject
 
/// appID
@property (nonatomic, assign) NSInteger appID;

/// appSign
@property (nonatomic, copy) NSString *appSign;

/// AI 模型资源的绝对路径
@property (nonatomic, copy) NSString *AIPath;

/// Unityframework 的路径，如果不填默认为app目录下的Frameworks/UnityFramework.framework
@property (nonatomic, copy) NSString *unityFrameworkPath;

/// UnityFramework.framework 的BundleID
@property (nonatomic, copy) NSString *unityBundleID;

/// SDK 支持的最小内存，小于该内存，不初始化 ZegoAvatarSDK
@property (nonatomic, assign) NSInteger minMemory;

@end

/// AI 推理出来的表情信息类
@interface ZegoExpression : NSObject

/// 脸部特征数据
@property (nonatomic, assign) float *expressions;

/// 头部转动 X 轴数值
@property (nonatomic, assign) float angleX;

/// 头部转动 Y 轴数值
@property (nonatomic, assign) float angleY;

/// 头部转动 Z 轴数值
@property (nonatomic, assign) float angleZ;

/// 时间戳
@property (nonatomic, assign) long timeStamp;

/// 表情信息类转 json 字符串
///
/// @return 转换后的 json 字符串
- (NSString *)expressionToJson;

/// json 字符串转表情信息类
///
/// @param jsonString 表情数据 json 字符串
/// @return 转换后的表情信息类
+ (ZegoExpression *)jsonToExpression:(NSString *)jsonString;

/// 表情数据与另一个表情混合
///
/// Description: self = self * blendScale + exp * (1 - blendScale)
///
/// @param blendScale 混合系数
/// @param exp 另一个表情
- (void)blendExpression:(float)blendScale exp:(ZegoExpression *)exp;

@end

/// AI 引擎胡子信息
@interface ZegoBeardInfo : NSObject

/// 有无胡子
@property (nonatomic, assign) BOOL has;

/// 上边有无胡子
@property (nonatomic, assign) BOOL top;

/// 下边有无胡子
@property (nonatomic, assign) BOOL bottom;

/// 左右有无胡子
@property (nonatomic, assign) BOOL leftAndRight;

@end

/// 头发信息
@interface ZegoHairInfo : NSObject

/// 头发长度
@property (nonatomic, assign) ZegoHairLengthType length;

/// 头发刘海
@property (nonatomic, assign) ZegoHairBangsType bangs;

/// 头发马尾
@property (nonatomic, assign) ZegoHairPonytailType ponytail;

@end

/// 人脸特征（ZegoInteractEngine返回的特征)
/// 
/// Description: 此结构还未稳定，后续可能会有调整。
@interface ZegoFaceFeature : NSObject

/// 性别: 0:男，1:女
@property (nonatomic, assign) ZegoGenderType gender;

/// 是否带眼镜
@property (nonatomic, assign) BOOL glasses;

/// 脸部形状（key：ZegoFaceShapeType， value：对应部位的比例系数）
@property (nonatomic, retain) NSDictionary<NSNumber *, NSNumber *> *faceShapeFeatures;

/// 胡子
@property (nonatomic, retain) ZegoBeardInfo *beard;

/// 头发
@property (nonatomic, retain) ZegoHairInfo *hair;

/// 脸型
@property (nonatomic, assign) int faceShape;

/// 鼻型
@property (nonatomic, assign) int noseShape;

/// 唇型
@property (nonatomic, assign) int lipShape;

/// 眼型
@property (nonatomic, assign) int eyeShape;

@end

/// Avatar 视频录制配置信息
@interface ZegoRecordConfig : NSObject

/// 视频录制后保存的路径
@property (nonatomic, copy) NSString *videoPath;

/// 需要录制的宽度
@property (nonatomic, assign) int scaleWidth;

/// 是否同时录制音频， 默认为 NO
@property (nonatomic, assign) BOOL recordAudio;

/// 录制模式 1: 带透明度的 mov，2: 不带透明度的mp4，默认mp4。
@property (nonatomic, assign) ZegoAvatarRecordMode recordMode;

@end

/// 获取 Avatar 视图纹理配置
@interface AvatarCaptureConfig : NSObject

/// 初始化方法
///
/// @param width 纹理宽度
/// @param height 纹理高度
- (id)initWithWidth:(int)width height:(int)height;

/// 纹理宽度
@property (nonatomic, assign) int width;

/// 纹理高度
@property (nonatomic, assign) int height;

@end

/// 图像数据的结构体
@interface ZegoImageParam : NSObject

/// 图像颜色格式
@property (nonatomic, assign) ZegoImageFormat format;

/// 图像宽度
@property (nonatomic, assign) int width;

/// 图像高度
@property (nonatomic, assign) int height;

/// 图像的旋转角度
@property (nonatomic, assign) int rotation;

/// 图像是否是镜像的
@property (nonatomic, assign) BOOL isMirrored;

/// 图像时间戳
@property (nonatomic, assign) long timestamp;

@end

/// 装扮类型转换器
@interface ZegoAvatarMakeupTypeTransformer : NSObject

/// 装扮类型字符串转枚举
///
/// @param string 装扮类型字符串
/// @return 装扮类型枚举
+ (ZegoAvatarMakeupType)makeupStringToType:(NSString *)string;

/// 装扮类型枚举转字符串
///
/// @param type 装扮类型枚举
/// @return 装扮类型字符串
+ (NSString *)makeupTypeToString:(ZegoAvatarMakeupType)type;

@end

#endif /* ZegoTypes_h */
